# -*- coding: utf-8 -*-

"""
CronAlertBackendMixin
===============

Questo mixin Backend fornisce i metodi di base e la modalità di inizializzazione del backend per l'invio di alert 
legati alla non esecuzione dei JOB.

Può accadere infatti che, per diversi motivi, l'esecuzione di un job non venga mai completata e questo matine lo 
stato del job in "RUNNING" impedendo le successive esecuzioni previste. 

Questo backend notifica le utenze indicate qualora si presenti il problema.

Classi
========

.. autoclass:: CronAlertBackendMixin
   :members:

"""
from django.template.loader import render_to_string


class CronAlertBackendMixin:
    """CronAlertBackendMixin"""

    text_template_path = "thx/cron/alert/cron_alert_default_template.txt"

    def __init__(self, job, *args, **kwargs):
        self.job = job

    def send_alert(self):
        raise NotImplementedError(f"{self.__class__.__name__} must implement send_alert()")

    def get_message(self):
        message = self.get_text_message()
        if not message:
            message = f"Cron job ({self.job.name}) didn't start since" \
                      f" {self.job.date_last_modify.strftime('%Y-%m-%d %H:%M:%S')}."
        return message

    def get_text_message(self):
        if self.text_template_path:
            return render_to_string(self.text_template_path, self.job.__dict__)
